# -*- coding: utf-8 -*-

"""
:copyright: (c) 2012 by the dot2code Team, see AUTHORS.txt for more details.
:license: GPL, see LICENSE.txt for more details.
"""

from __future__ import absolute_import
from django.utils.translation import ugettext_lazy as _

DEFAULT_SUCCESS_MESSAGE = _('All changes have been saved!')
DEFAULT_ERROR_MESSAGE = _("We are sorry, but the request couldn't be processed. Please, try again later.")
DEFAULT_FORM_ERROR_MESSAGE = _('Form contains errors! Please review it and try again.')
